@@ -1,5 +1,105 @@
-const<-function(x) x
 
+
+#' Fit Cox model with partly timevarying effects.
+#' 
+#' Fits proportional hazards model with some effects time-varying and some
+#' effects constant.  Time dependent variables and counting process data
+#' (multiple events per subject) are possible.
+#' 
+#' Resampling is used for computing p-values for tests of timevarying effects.
+#' 
+#' The modelling formula uses the standard survival modelling given in the
+#' \bold{survival} package.
+#' 
+#' The data for a subject is presented as multiple rows or 'observations', each
+#' of which applies to an interval of observation (start, stop].  When counting
+#' process data with the )start,stop] notation is used the 'id' variable is
+#' needed to identify the records for each subject. The program assumes that
+#' there are no ties, and if such are present random noise is added to break
+#' the ties.
+#' 
+#' @param formula a formula object with the response on the left of a '~'
+#' operator, and the independent terms on the right as regressors. The response
+#' must be a survival object as returned by the `Surv' function. Time-invariant
+#' regressors are specified by the wrapper const(), and cluster variables (for
+#' computing robust variances) by the wrapper cluster().
+#' @param data a data.frame with the variables.
+#' @param start.time start of observation period where estimates are computed.
+#' @param max.time end of observation period where estimates are computed.
+#' Estimates thus computed from [start.time, max.time]. Default is max of data.
+#' @param robust to compute robust variances and construct processes for
+#' resampling. May be set to 0 to save memory.
+#' @param id For timevarying covariates the variable must associate each record
+#' with the id of a subject.
+#' @param clusters cluster variable for computation of robust variances.
+#' @param n.sim number of simulations in resampling.
+#' @param weighted.test to compute a variance weighted version of the
+#' test-processes used for testing time-varying effects.
+#' @param residuals to returns residuals that can be used for model validation
+#' in the function cum.residuals
+#' @param covariance to compute covariance estimates for nonparametric terms
+#' rather than just the variances.
+#' @param Nit number of iterations for score equations.
+#' @param bandwidth bandwidth for local iterations. Default is 50 \% of the
+#' range of the considered observation period.
+#' @param method Method for estimation. This refers to different
+#' parametrisations of the baseline of the model. Options are "basic" where the
+#' baseline is written as \eqn{\lambda_0(t) = \exp(\alpha_0(t))} or the
+#' "breslow" version where the baseline is parametrised as \eqn{\lambda_0(t)}.
+#' @param degree gives the degree of the local linear smoothing, that is local
+#' smoothing. Possible values are 1 or 2.
+#' @return Returns an object of type "timecox". With the following arguments:
+#' \item{cum}{cumulative timevarying regression coefficient estimates are
+#' computed within the estimation interval.} \item{var.cum}{the martingale
+#' based pointwise variance estimates.  } \item{robvar.cum}{robust pointwise
+#' variances estimates.  } \item{gamma}{estimate of parametric components of
+#' model.  } \item{var.gamma}{variance for gamma.  } \item{robvar.gamma}{robust
+#' variance for gamma.  } \item{residuals}{list with residuals. Estimated
+#' martingale increments (dM) and corresponding time vector (time).}
+#' \item{obs.testBeq0}{observed absolute value of supremum of cumulative
+#' components scaled with the variance.} \item{pval.testBeq0}{p-value for
+#' covariate effects based on supremum test.} \item{sim.testBeq0}{resampled
+#' supremum values.} \item{obs.testBeqC}{observed absolute value of supremum of
+#' difference between observed cumulative process and estimate under null of
+#' constant effect.} \item{pval.testBeqC}{p-value based on resampling.}
+#' \item{sim.testBeqC}{resampled supremum values.}
+#' \item{obs.testBeqC.is}{observed integrated squared differences between
+#' observed cumulative and estimate under null of constant effect.}
+#' \item{pval.testBeqC.is}{p-value based on resampling.}
+#' \item{sim.testBeqC.is}{resampled supremum values.}
+#' \item{conf.band}{resampling based constant to construct robust 95\% uniform
+#' confidence bands. } \item{test.procBeqC}{observed test-process of difference
+#' between observed cumulative process and estimate under null of constant
+#' effect over time.  } \item{sim.test.procBeqC}{list of 50 random realizations
+#' of test-processes under null based on resampling.}
+#' \item{schoenfeld.residuals}{Schoenfeld residuals are returned for "breslow"
+#' parametrisation.}
+#' @author Thomas Scheike
+#' @references Martinussen and Scheike, Dynamic Regression Models for Survival
+#' Data, Springer (2006).
+#' @keywords survival
+#' @examples
+#' 
+#' data(sTRACE)
+#' # Fits time-varying Cox model 
+#' out<-timecox(Surv(time/365,status==9)~age+sex+diabetes+chf+vf,
+#' data=sTRACE,max.time=7,n.sim=100)
+#' 
+#' summary(out)
+#' par(mfrow=c(2,3))
+#' plot(out)
+#' par(mfrow=c(2,3))
+#' plot(out,score=TRUE)
+#' 
+#' # Fits semi-parametric time-varying Cox model
+#' out<-timecox(Surv(time/365,status==9)~const(age)+const(sex)+
+#' const(diabetes)+chf+vf,data=sTRACE,max.time=7,n.sim=100)
+#' 
+#' summary(out)
+#' par(mfrow=c(2,3))
+#' plot(out)
+#' 
+##' @export
 timecox<-function(formula=formula(data),data=sys.parent(),
 start.time=0,max.time=NULL,id=NULL,clusters=NULL,
 n.sim=1000,residuals=0,robust=1,Nit=20,bandwidth=0.5,
@@ -181,8 +281,9 @@ method="basic",weighted.test=0,degree=1,covariance=0)
   return(ud); 
 }
 
+##' @export
 "plot.timecox" <-  function (x,..., pointwise.ci=1,
-hw.ci=0, sim.ci=0, robust=0, specific.comps=FALSE,level=0.05,
+hw.ci=0, sim.ci=0, robust.ci=0, col=NULL, specific.comps=FALSE,level=0.05,
 start.time = 0,
 stop.time = 0, add.to.plot=FALSE, mains=TRUE, xlab="Time",
 ylab ="Cumulative coefficients",score=FALSE)
@@ -194,7 +295,7 @@ from Cox-Aalen function")
   if (score==FALSE) plot.cums(object,
         pointwise.ci=pointwise.ci,
         hw.ci=hw.ci,
-        sim.ci=sim.ci, robust=robust,
+        sim.ci=sim.ci, robust.ci=robust.ci,col=col,
         specific.comps=specific.comps,level=level,
         start.time = start.time, stop.time = stop.time,
         add.to.plot=add.to.plot,
@@ -204,6 +305,7 @@ from Cox-Aalen function")
                   xlab=xlab,ylab =ylab);
 }
 
+##' @export
 "print.timecox"<-
 function (x,...) 
 {
@@ -228,6 +330,7 @@ if (is.null(timecox.object$gamma)==TRUE) semi<-FALSE else semi<-TRUE
 }
 
 
+##' @export
 "summary.timecox" <-
 function (object,..., digits = 3) 
 {
@@ -271,6 +374,7 @@ function (object,..., digits = 3)
   cat("\n")
 }
 
+##' @export
 coef.timecox<- function(object,..., digits=3) {
    coefBase(object,digits=digits)
 }
